package fri.util.pdfbox.model;

import java.io.IOException;
import java.util.Arrays;

import fri.util.pdfbox.model.components.PdfBoxNewspaperColumns;
import fri.util.pdfbox.model.components.PdfBoxParagraph;
import fri.util.pdfbox.model.components.PdfBoxRectangle;
import fri.util.pdfbox.model.components.PdfBoxTable;
import fri.util.pdfbox.model.components.PdfBoxTextComponent;
import fri.util.pdfbox.model.geometry.OpenRectangle;
import fri.util.pdfbox.model.geometry.Padding;
import fri.util.pdfbox.model.geometry.Point;

public class Example
{
    public static void main(String[] args) throws Exception {
        final PdfBoxDocument document = new PdfBoxDocument(null, null, new Padding(20, 20));
        Example test = new Example();
        test.drawNewspaperColumns(document);
        test.drawTextColumn(document);
        test.drawTable(document);
        final String fileName = "PdfBoxWriter.pdf";
        document.saveAndClose(fileName);
        System.out.println("Wrote "+fileName);
    }
    
    
    private String text = 
        "%By default when you write a (long) text using PDPageContentStream#showText() it is printed on a single line. "+
        "We need to calculate how many words will fit on a single line and then write the text to the document. "+
        "Here comes a newline:"+
        "\n"+
        "Here comes a long text without spaces: "+
        "Loremipsumdolorsitametconsecteturadipiscingelitseddoeiusmodtemporincididuntutlaboreetdoloremagnaaliqua. "+
        "\n"+
        "Several newlines are preserved:"+
        "\n"+
        "\n"+
        "Redundant        spaces         get removed,       this is called normalizing. Here comes text with tabs: "+
        "laboris\tnisi\tut\taliquip\tex\tea\tcommodo\tconsequat.\tDuis\taute\tirure\tdolor\tin\treprehenderit\tin\tut "+
        "voluptate velit esse cillum dolore eu fugiat nulla pariatur. "+
        "http://longlonglongurlwithoutend/longlonglongurlwithoutend/longlonglongurlwithoutend. "+
        "Font descent test: qgjpy";

    private final String multiPageText = text+"\n------\n"+text+"\n=======\n"+text+"\n******\n"+text;
    
    private void drawTextColumn(PdfBoxDocument document) throws IOException {
        final PdfBoxTextComponent textArea = new PdfBoxParagraph(document, null);
        final float textBlockWidth = 120f;
        final WriteState writeState = textArea.drawTextColumn(multiPageText, new OpenRectangle(textBlockWidth));
        
        // go to current page
        PdfBoxPageWriter writer = document.getOrCreateWriter();
        final PdfBoxRectangle rectangle = new PdfBoxRectangle(writer);
        rectangle.draw(writeState.consumedRectangle);
        
        document.closePage();
    }
    
    
    private void drawNewspaperColumns(PdfBoxDocument document) throws IOException {
        final float marginLeft = 0f; //55f;
        final float marginTop = 0f; //40f;
        final float paddingRight = 0f; //20f;
        final float columnWidth = 130f;
        final float columnPaddingRight = 0f; //10f;
        final PdfBoxNewspaperColumns textArea = new PdfBoxNewspaperColumns(document, null, columnWidth, paddingRight);
        final String text = multiPageText + multiPageText + multiPageText + multiPageText;
        textArea.drawTextColumns(text, new Point(marginLeft, marginTop), columnPaddingRight);
        
        document.closePage();
    }


    private String[][] tableData = {
        new String[] { "Lorem", "ipsum", "dolor", "sit", "amet", "consectetur", "adipiscin" },
        new String[] { "gelit", "sed", "eius", "mod", "tempor", "incididunt", "ut" },
        new String[] { "labore", "et", "dolore", "sit", "magna carta", "aliqua", "piscis" },
        new String[] { "Lorem ipsum", "dolor sit amet", "consectetur adipiscin", "gelit sed doeius mod tempor incididunt ut", "dolore sit magna aliqua piscis", "amen", "et alii" },
        new String[] { "Aleae", "iactae", "sunt", "ma", "tibi", "prosectuntur", "ade." },
    };
    
    private String[][] multiPageTableData;
    
    {
        int MULTIPLY = 5;   // leads to 5 * tableData.length = 25 table rows
        multiPageTableData = new String[MULTIPLY * tableData.length][];
        for (int i = 0; i < MULTIPLY; i++)  // write row data
            for (int j = 0; j < tableData.length; j++)
                multiPageTableData[i * tableData.length + j] = Arrays.copyOf(tableData[j], tableData[j].length);
        
        for (int i = 0; i < multiPageTableData.length; i++)  // prepend coordinates to any cell
            for (int j = 0; j < multiPageTableData[i].length; j++)
                multiPageTableData[i][j] = "("+(i + 1)+"/"+(j + 1)+") "+multiPageTableData[i][j];
    }
    
    private void drawTable(PdfBoxDocument document) throws IOException {
        final float marginLeft = 0f; //20f;
        final float[] columnWidths = new float[] { 60f, 50f, 80f, 100f, 50f, 80f, 50f };
        final PdfBoxTable.View tableView = new PdfBoxTable.View(columnWidths, 4f, 8f);
        final PdfBoxTable table = new PdfBoxTable(document, null, tableView);
        table.draw(multiPageTableData, new OpenRectangle(new Point(marginLeft, 0f)));
        
        document.closePage();
    }
    
}
