package fri.util.pdfbox.model.components;

import java.io.IOException;

import fri.util.pdfbox.model.PdfBoxPageWriter;
import fri.util.pdfbox.model.geometry.Font;
import fri.util.pdfbox.model.geometry.OpenRectangle;

/**
 * A Component is atomic, it will not be broken across pages.
 * 
 * @author fri May 4, 2019
 */
public class PdfBoxComponent
{
    private PdfBoxPageWriter writer;
    private Font font;

    /**
     * @param writer required, the PDF page-stream to write into.
     * @param font optional, the font to be used by any write-method.
     */
    protected PdfBoxComponent(PdfBoxPageWriter writer, Font font) {
        assert writer != null;
        
        this.writer = writer;
        this.font = (font != null) ? font : new Font();
    }
    
    
    public Font getFont()    {
        return font;
    }
    
    public void setFont(Font font)    {
        this.font = font;
    }
    
    
    /** @return the current writer, never null. */
    protected final PdfBoxPageWriter getWriter() {
        return writer;
    }
    
    /** Closes the current writer and sets the new one. */
    protected final void setWriter(PdfBoxPageWriter writer) throws IOException {
        if (writer != getWriter())
            getWriter().close();

        this.writer = writer;
    }
    
    /** Makes sure the given rectangle doesn't exceed the page. */
    protected final float pageAdjustedWidth(OpenRectangle rectangle) {
        final float maxWidth = getWriter().pageDimension().width - rectangle.topLeft.x;
        return (rectangle.width > 0 && rectangle.width <= maxWidth) ? rectangle.width : maxWidth;
    }
}
