package fri.util.pdfbox.model.components;

import java.io.IOException;

import fri.util.pdfbox.model.PdfBoxDocument;
import fri.util.pdfbox.model.PdfBoxPageWriter;
import fri.util.pdfbox.model.WriteState;
import fri.util.pdfbox.model.geometry.Font;
import fri.util.pdfbox.model.geometry.OpenRectangle;
import fri.util.pdfbox.model.geometry.Point;
import fri.util.pdfbox.model.pagination.NewspaperColumnsPageBreakListener;

/**
 * Prints text in a newspaper layout into several columns, using the whole page.
 * 
 * @author fri May 4, 2019
 */
public class PdfBoxNewspaperColumns
{
    private final PdfBoxTextComponent textComponent;
    private final float columnWidth;
    
    /**
     * @param document required, the PDF document to write into.
     * @param font optional, the font to be used by any write-method.
     * @param columnWidth the horizontal width of one newspaper text column.
     * @throws IOException when PDFBox throws one.
     */
    public PdfBoxNewspaperColumns(PdfBoxDocument document, Font font, float columnWidth, float pagePaddingRight) throws IOException {
        final PdfBoxPageWriter writer = document.getOrCreateWriter();
        this.textComponent = new PdfBoxTextComponent(writer, font)    {
            @Override
            protected PageBreakListener newPageBreakListener() {
                return new NewspaperColumnsPageBreakListener(document, writer.pageDimension().minusWidth(pagePaddingRight), columnWidth);
            }
        };
        this.columnWidth = columnWidth;
    }

    /**
     * @param text the text to be printed in newspaper layout.
     * @param topLeft the top left point where to start to print,
     *      and never be above on first page, and never be left of on all pages.
     * @param columnPaddingRight space at right side of each column (even the rightmost).
     * @return the consumed space.
     * @throws IOException when PDFBox throws one.
     */
    public WriteState drawTextColumns(String text, Point topLeft, float columnPaddingRight) throws IOException {
        return textComponent.drawTextColumn(text, new OpenRectangle(topLeft, columnWidth - columnPaddingRight));
    }
    
}
