package fri.util.pdfbox.model.geometry;

import java.io.IOException;

import org.apache.pdfbox.pdmodel.font.PDFont;
import org.apache.pdfbox.pdmodel.font.PDType1Font;

/**
 * Font dimensions, immutable.
 * 
 * @author fri May 5, 2019
 */
public class Font
{
    /** The PDFBox font. */
    public final PDFont font;
    /** For a 10-point font the fontSize would be 10. */
    public final float fontSize;
    /** What of the upper-case letter is above the baseline. */
    public final float ascent;
    /** What of the letter is below the baseline (g, j, p, q, y), positive. */
    public final float descent;
    /** Line height for the font is 150% of ascent, representing ascent + descent + leading (space between lines). */
    public final float lineHeight;
    /** Where to locate the font writer, the font sits upon the baseline: lineHeight - descent. */
    public final float baseLine;

    public Font() {
        this(PDType1Font.HELVETICA);
    }
    
    public Font(PDFont font) {
        this(font, 10f);
    }
    
    public Font(PDFont font, float fontSize) {
        assert font != null && fontSize > 0;
        
        this.font = font;
        this.fontSize = 10f;
        this.ascent = fontSize * font.getFontDescriptor().getAscent() / 1000f;  // getCapHeight()
        this.descent = fontSize * -font.getFontDescriptor().getDescent() / 1000f;
        this.lineHeight = ascent * 1.5f; // standard line height is 150% of font height
        this.baseLine = lineHeight - (descent * 1.2f);  // some interline spacing
    }
    
    public float stringWidth(String singleLineText) throws IOException {
        return fontSize * font.getStringWidth(singleLineText) / 1000f;
    }
    
}
