package fri.util.pdfbox.model.geometry;

/**
 * 2-dimensional rectangle.
 * Coordinate origin x=0/y=0 is in left upper corner.
 * Positive y goes down, positive x goes right.
 * 
 * @author fridell May 9, 2019
 */
public class Rectangle
{
    public final Point topLeft;
    public final Point bottomRight;
    
    public Rectangle(Point topLeft, Point bottomRight) {
        this.topLeft = topLeft;
        this.bottomRight = bottomRight;
    }
    
    public Rectangle(Point topLeft, Dimension dimension) {
        this(topLeft, topLeft.bottomRight(dimension));
    }
    
    public float width()    {
        return bottomRight.x - topLeft.x;
    }
    public float height()    {
        return bottomRight.y - topLeft.y;
    }

    public VerticalSection verticalSection() {
        return new VerticalSection(topLeft.y, bottomRight.y);
    }

    public HorizontalSection horizontalSection() {
        return new HorizontalSection(topLeft.x, bottomRight.x);
    }
    
    public Rectangle shrink(Padding padding) {
        return new Rectangle(
                new Point(topLeft.x + padding.left, topLeft.y + padding.top),
                new Point(bottomRight.x - padding.right, bottomRight.y - padding.bottom)
            );
    }

}
