package fri.util.pdfbox.model.pagination;

import java.io.IOException;

import fri.util.pdfbox.model.PdfBoxDocument;
import fri.util.pdfbox.model.components.PdfBoxMultiPageComponent;
import fri.util.pdfbox.model.components.PdfBoxMultiPageComponent.PageBreak;
import fri.util.pdfbox.model.geometry.Point;
import fri.util.pdfbox.model.geometry.VerticalSection;

public class DefaultPageBreakListener implements PdfBoxMultiPageComponent.PageBreakListener
{
    protected final PdfBoxDocument document;
    protected final VerticalSection verticalSection;
    
    public DefaultPageBreakListener(PdfBoxDocument document, float pageHeight) {
        this(document, new VerticalSection(0f, pageHeight));
    }
    
    /** Coordinate 0/0 is left bottom corner of page. */
    public DefaultPageBreakListener(PdfBoxDocument document, VerticalSection verticalSection) {
        assert document != null && verticalSection != null;
        
        this.document = document;
        this.verticalSection = verticalSection;
    }
    
    @Override
    public PageBreak willAdvance(Point next) throws IOException {
        return atBottom(next.y) ? new PageBreak(new Point(next.x, verticalSection.top), document.newWriter()) : null;
    }
    
    protected final boolean atBottom(float nextY) throws IOException {
        return nextY > verticalSection.bottom;
    }
}
