package fri.util.pdfbox.model.pagination;

import java.io.IOException;

import fri.util.pdfbox.model.PdfBoxDocument;
import fri.util.pdfbox.model.components.PdfBoxMultiPageComponent.PageBreak;
import fri.util.pdfbox.model.geometry.Dimension;
import fri.util.pdfbox.model.geometry.HorizontalSection;
import fri.util.pdfbox.model.geometry.Point;
import fri.util.pdfbox.model.geometry.Rectangle;

public class NewspaperColumnsPageBreakListener extends DefaultPageBreakListener
{
    protected final HorizontalSection horizontalSection;
    protected final float columnWidth;
    
    public NewspaperColumnsPageBreakListener(PdfBoxDocument document, Dimension pageDimension, float columnWidth) {
        this(document, new Rectangle(new Point(), pageDimension), columnWidth);
    }
    
    public NewspaperColumnsPageBreakListener(PdfBoxDocument document, Rectangle window, float columnWidth) {
        super(document, window.verticalSection());
        
        assert columnWidth > 0;
        
        this.horizontalSection = window.horizontalSection();
        this.columnWidth = columnWidth;
    }
    
    @Override
    public PageBreak willAdvance(Point next) throws IOException {
        if (atBottom(next.y) == false)
            return null;
        
        final float x = next.x + columnWidth;
        if (atRight(x + columnWidth) == false)
            return new PageBreak(new Point(x, verticalSection.top), null);
        
        return super.willAdvance(new Point(horizontalSection.left, next.y));
    }
    
    protected final boolean atRight(float nextX)    {
        return nextX > horizontalSection.right;
    }
}
