package pdfboxtest;

import java.io.IOException;

import org.apache.pdfbox.pdmodel.PDDocument;
import org.apache.pdfbox.pdmodel.PDPage;
import org.apache.pdfbox.pdmodel.PDPageContentStream;
import org.apache.pdfbox.pdmodel.common.PDRectangle;
import org.apache.pdfbox.pdmodel.font.PDFont;
import org.apache.pdfbox.pdmodel.font.PDType1Font;

public class HelloWorld
{
    public static void main(String[] args) throws IOException {
        final PDDocument document = new PDDocument();
        
        final PDFont font = PDType1Font.HELVETICA;
        final float fontSize = 10;
        final float ascent = fontSize * font.getFontDescriptor().getAscent() / 1000;
        final float descent = fontSize * -font.getFontDescriptor().getDescent() / 1000;
        final float widthOfM = fontSize * font.getStringWidth("M") / 1000;
        System.out.println("Font size: "+fontSize+", ascent: "+ascent+", descent: "+descent+", width of 'M': "+widthOfM);
        
        final PDRectangle pageSize = PDRectangle.A4;
        final PDPage page = new PDPage(pageSize);
        document.addPage(page);
        
        final PDRectangle pageBox = page.getMediaBox();
        final float width = pageBox.getWidth();
        final float height = pageBox.getHeight();
        System.out.println("PDF page w="+Math.round(width)+"/h="+Math.round(height));
        
        final float lineHeight = (ascent + descent) * 1.5f; // standard line height is 150% of font height
        float startX = pageBox.getLowerLeftX();
        float startY = pageBox.getUpperRightY();
        
        final PDPageContentStream contentStream = new PDPageContentStream(document, page);
        contentStream.beginText();
        contentStream.setFont(font, fontSize);
        contentStream.newLineAtOffset(startX, startY - lineHeight + descent); // set position to baseline of text
        contentStream.setLeading(lineHeight);
        contentStream.showText("First Line");
        // three alternatives to go to next line:
        contentStream.newLine();
        //contentStream.newLineAtOffset(0, -lineHeight); // relative to last given x, relative to last given y
        //contentStream.setTextMatrix(Matrix.getTranslateInstance(startX, startY - 2 * lineHeight));
        contentStream.showText("Second Line");
        contentStream.endText();
        
        contentStream.close();
        
        final String fileName = "HelloWorld.pdf";
        document.save(fileName);
        document.close();
        System.out.println("Wrote file: "+fileName);
    }

}
