package pdfboxtest;

import java.io.IOException;

import org.apache.pdfbox.pdmodel.PDDocument;
import org.apache.pdfbox.pdmodel.PDPage;
import org.apache.pdfbox.pdmodel.PDPageContentStream;
import org.apache.pdfbox.pdmodel.common.PDRectangle;
import org.apache.pdfbox.pdmodel.font.PDFont;
import org.apache.pdfbox.pdmodel.font.PDType1Font;

/**
 * Shows that trimBox doesn't have any influence on drawing.
 */
public class MediaBoxTrimBox
{
    public static void main(String[] args) throws IOException {
        final PDDocument document = new PDDocument();
        
        final PDFont font = PDType1Font.HELVETICA;
        final float fontSize = 10;
        final float ascent = fontSize * font.getFontDescriptor().getAscent() / 1000;
        final float descent = fontSize * -font.getFontDescriptor().getDescent() / 1000;
        final float lineHeight = (ascent + descent) * 1.5f;
        
        final PDRectangle pageSize = PDRectangle.A4;
        final PDPage page = new PDPage(pageSize);
        document.addPage(page);
        
        final PDRectangle mediaBox = page.getMediaBox();
        final PDRectangle trimBox = page.getTrimBox();
        System.out.println("BEFORE mediaBox: "+mediaBox+", trimBox: "+trimBox);
        page.setTrimBox(
            new PDRectangle(
                mediaBox.getLowerLeftX() + 40, mediaBox.getLowerLeftY() + 40, 
                mediaBox.getWidth() - 80, mediaBox.getHeight() - 80
            )
        );
        System.out.println("AFTER mediaBox: "+page.getMediaBox()+", trimBox: "+page.getTrimBox());
        
        float startX = mediaBox.getLowerLeftX();
        float startY = mediaBox.getUpperRightY();
        
        final PDPageContentStream contentStream = new PDPageContentStream(document, page);
        contentStream.beginText();
        contentStream.setFont(font, fontSize);
        contentStream.newLineAtOffset(startX, startY - lineHeight + descent);
        contentStream.showText("First Line");
        contentStream.newLineAtOffset(0, -lineHeight);
        contentStream.showText("Second Line");
        contentStream.endText();
        
        contentStream.close();
        
        final String fileName = "MediaBoxTrimBox.pdf";
        document.save(fileName);
        document.close();
        System.out.println("Wrote file: "+fileName);
    }

}
